ButtonStyleData class

A class to configure the theme of the button.

Constructors

ButtonStyleData({double? height, double? width, EdgeInsetsGeometry? padding, BoxDecoration? decoration, BoxDecoration? foregroundDecoration, int? elevation, WidgetStateProperty<Color?>? overlayColor})
Creates a ButtonStyleData. It's a class to configure the theme of the button.
const

Properties

decoration BoxDecoration?
The decoration of the Button
finalinherited
elevation int?
The elevation of the Button
finalinherited
foregroundDecoration BoxDecoration?
The decoration to paint in front of the Button
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
The height of the button
finalinherited
overlayColor WidgetStateProperty<Color?>?
Defines the ink response focus, hover, and splash colors.
final
padding EdgeInsetsGeometry?
The inner padding of the Button
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
The width of the button
finalinherited

Methods

copyWith({double? height, double? width, EdgeInsetsGeometry? padding, BoxDecoration? decoration, BoxDecoration? foregroundDecoration, int? elevation, WidgetStateProperty<Color?>? overlayColor}) ButtonStyleData
Create a clone of the current ButtonStyleData but with the provided parameters overridden.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited