barrierCoversButton property
Specifies whether the modal barrier should cover the dropdown button or not.
Defaults to true.
Implementation
final bool barrierCoversButton;
Specifies whether the modal barrier should cover the dropdown button or not.
Defaults to true.
final bool barrierCoversButton;