disabledHint property

Widget? disabledHint
final

A preferred placeholder widget that is displayed when the dropdown is disabled.

If no DropdownItem is selected and the dropdown is disabled (items or onChanged is null), this widget is displayed as a placeholder for the dropdown button's value.

Implementation

final Widget? disabledHint;