hint property
A placeholder widget that is displayed by the dropdown button.
If no DropdownItem is selected and the dropdown is enabled (items and onChanged are non-null), this widget is displayed as a placeholder for the dropdown button's value.
If no DropdownItem is selected and the dropdown is disabled and disabledHint is null, this widget is used as the placeholder.
Implementation
final Widget? hint;