multiValueListenable property

ValueListenable<Iterable<T>>? multiValueListenable
final

A ValueListenable that represents a list of the currently selected DropdownItems. It holds a list of type List<T>, where T represents the type of DropdownItem's value.

If the list is empty and the button is enabled, hint will be displayed if it is non-null.

If the list is empty and the button is disabled, disabledHint will be displayed if it is non-null. If disabledHint is null, then hint will be displayed if it is non-null.

Implementation

final ValueListenable<Iterable<T>>? multiValueListenable;