DropdownSearchData<T> class

A class to configure searchable dropdowns.

Constructors

Creates a DropdownSearchData.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
noResultsWidget Widget?
The widget to show when the search results are empty.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBarWidget Widget?
The widget to use for searchable dropdowns, such as search bar. It will be shown at the top of the dropdown menu.
final
searchBarWidgetHeight double?
The height of the searchBarWidget if used.
final
searchController TextEditingController?
The TextEditingController used for searchable dropdowns. If this is null, then it'll perform as a normal dropdown without searching feature.
final
searchMatchFn SearchMatchFn<T>?
The match function used for searchable dropdowns. If this is null, then _defaultSearchMatchFn will be used.
final

Methods

copyWith({TextEditingController? searchController, Widget? searchBarWidget, double? searchBarWidgetHeight, Widget? noResultsWidget, SearchMatchFn<T>? searchMatchFn}) DropdownSearchData<T>
Create a clone of the current DropdownSearchData but with the provided parameters overridden.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited