MenuItemStyleData class

A class to configure the theme of the dropdown menu items.

Constructors

Creates a MenuItemStyleData.
const

Properties

borderRadius BorderRadius?
The border radius of the menu item.
final
hashCode int
The hash code for this object.
no setterinherited
overlayColor WidgetStateProperty<Color?>?
Defines the ink response focus, hover, and splash colors.
final
padding EdgeInsetsGeometry?
The padding applied to each menu item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedMenuItemBuilder SelectedMenuItemBuilder?
A builder to customize the selected menu item.
final
useDecorationHorizontalPadding bool
Whether to use the horizontal padding from decoration.contentPadding instead of padding, applicable only when using DropdownButtonFormField2.
final

Methods

copyWith({EdgeInsetsGeometry? padding, BorderRadius? borderRadius, WidgetStateProperty<Color?>? overlayColor, SelectedMenuItemBuilder? selectedMenuItemBuilder}) MenuItemStyleData
Create a clone of the current MenuItemStyleData but with the provided parameters overridden.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited