useDecorationHorizontalPadding property

bool useDecorationHorizontalPadding
final

Whether to use the horizontal padding from decoration.contentPadding instead of padding, applicable only when using DropdownButtonFormField2.

If true, the horizontal padding defined in decoration.contentPadding will be applied, ensuring consistency with the form field's padding.

Implementation

final bool useDecorationHorizontalPadding;