valueListenable property
A ValueListenable that represents the value of the currently selected DropdownItem.
It holds a value of type T?, where T represents the type of DropdownItem's value.
If the value is null and the button is enabled, hint will be displayed if it is non-null.
If the value is null and the button is disabled, disabledHint will be displayed if it is non-null. If disabledHint is null, then hint will be displayed if it is non-null.
Implementation
final ValueListenable<T?>? valueListenable;