decoration property
The decoration to show around the dropdown button form field.
By default, draws a horizontal line under the dropdown button field but can be configured to show an icon, label, hint text, and error text.
Implementation
final InputDecoration decoration;